pub enum CrocEvent {
Hashing(Progress),
SendingInfo(FileInfo),
ReceivingInfo(FileInfo),
CodeGenerated(String),
SendingTo(Relay),
ReceivingFrom(Relay),
Sending(Progress),
Receiving(Progress),
Done,
Unknown(String),
EOF,
}Expand description
A collection representing an event that happened in the running croc application.
Variants
Hashing(Progress)
A hashing operation is in progress.
SendingInfo(FileInfo)
Information about a file being sent.
ReceivingInfo(FileInfo)
Information about a file being received.
CodeGenerated(String)
The connection code has been generated.
SendingTo(Relay)
The transfer is sending data to the specified relay/IP.
ReceivingFrom(Relay)
The transfer is receiving data from the specified relay/IP.
Sending(Progress)
A file is currently being sent.
Receiving(Progress)
A file is currently being received.
Done
The transfer has completed successfully.
Unknown(String)
An unknown line for the parser has been received.
EOF
The process has reached EOF.